#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_scheduler.interfaces.zodb import IZODBPackingTask, IZODBPackingTaskInfo
from pyams_skin.interfaces.viewlet import IToolbarAddingMenu
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.interfaces import VIEW_SYSTEM_PERMISSION, MANAGE_SYSTEM_PERMISSION
from zope.component.interfaces import ISite

# import packages
from pyams_form.form import AJAXAddForm, AJAXEditForm
from pyams_pagelet.pagelet import pagelet_config
from pyams_scheduler.zmi.scheduler import SchedulerTasksTable
from pyams_scheduler.zmi.task import TaskBaseAddForm
from pyams_scheduler.zodb import ZODBPackingTask
from pyams_skin.viewlet.toolbar import ToolbarMenuItem
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminDialogEditForm
from pyramid.view import view_config
from z3c.form import field

from pyams_scheduler import _


@viewlet_config(name='add-scheduler-zodb-task.menu', context=ISite, layer=IPyAMSLayer,
                view=SchedulerTasksTable, manager=IToolbarAddingMenu,
                permission=MANAGE_SYSTEM_PERMISSION, weight=5)
class ZODBTaskAddMenu(ToolbarMenuItem):
    """ZODB packing task add menu"""

    label = _("Add ZODB packing task...")
    label_css_class = 'fa fa-fw fa-database'
    url = 'add-scheduler-zodb-task.html'
    modal_target = True


@pagelet_config(name='add-scheduler-zodb-task.html', context=ISite, layer=IPyAMSLayer,
                permission=MANAGE_SYSTEM_PERMISSION)
class ZODBTaskAddForm(TaskBaseAddForm):
    """ZODB packing task add form"""

    legend = _("Add ZODB packing task")
    icon_css_class = 'fa fa-fw fa-database'

    ajax_handler = 'add-scheduler-zodb-task.json'
    task_factory = ZODBPackingTask


@view_config(name='add-scheduler-zodb-task.json', context=ISite, request_type=IPyAMSLayer,
             permission=MANAGE_SYSTEM_PERMISSION, renderer='json', xhr=True)
class ZODBTaskAJAXAddForm(AJAXAddForm, ZODBTaskAddForm):
    """ZODB packing task add form, AJAX view"""


@pagelet_config(name='settings.html', context=IZODBPackingTask, layer=IPyAMSLayer, permission=VIEW_SYSTEM_PERMISSION)
class ZODBTaskEditForm(AdminDialogEditForm):
    """ZODB packing task edit form"""

    @property
    def title(self):
        translate = self.request.localizer.translate
        return translate(_("Scheduler task: {0}")).format(self.context.name)

    legend = _("Edit task settings")
    icon_css_class = 'fa fa-fw fa-database'

    fields = field.Fields(IZODBPackingTaskInfo)
    ajax_handler = 'settings.json'
    edit_permission = MANAGE_SYSTEM_PERMISSION


@view_config(name='settings.json', context=IZODBPackingTask, request_type=IPyAMSLayer,
             permission=MANAGE_SYSTEM_PERMISSION, renderer='json', xhr=True)
class ZODBTaskAJAXEditForm(AJAXEditForm, ZODBTaskEditForm):
    """ZODB packing task edit form, AJAX view"""
